@@ -7,18 +7,18 @@ require 'bake/modernize'
 require 'markly'
 
 def contributing
-	update(root: Dir.pwd)
+	if conduct_path = Dir["conduct.md"]
+		FileUtils.rm_f(conduct_path)
+	end
+	
 	update_contributing(File.join(Dir.pwd, 'readme.md'))
 end
 
-def update(root:)
-	template_root = Bake::Modernize.template_path_for('contributing')
-	Bake::Modernize.copy_template(template_root, root)
-end
-
 private
 
 DEFAULT_CONTRIBUTING = <<~EOF
+## Contributing
+
 We welcome contributions to this project.
 
 1.  Fork it.
@@ -26,6 +26,14 @@ We welcome contributions to this project.
 3.  Commit your changes (`git commit -am 'Add some feature'`).
 4.  Push to the branch (`git push origin my-new-feature`).
 5.  Create new Pull Request.
+
+### Developer Certificate of Origin
+
+This project uses the [Developer Certificate of Origin](https://developercertificate.org/). All contributors to this project must agree to this document to have their contributions accepted.
+
+### Contributor Covenant
+
+This project is governed by [Contributor Covenant](https://www.contributor-covenant.org/). All contributors and participants agree to abide by its terms.
 EOF
 
 def update_contributing(readme_path)
@@ -33,36 +41,9 @@ def update_contributing(readme_path)
 	
 	replacement = Markly.parse(DEFAULT_CONTRIBUTING)
 	
-	node = root.first_child
+	return unless node = root.find_header("Contributing")
 	
-	while node
-		if node.type == :header && node.to_plaintext =~ /Contributing/
-			break
-		end
-		
-		node = node.next
-		return unless node
-	end
-	
-	contributing_header = node
-	node = node.next
-	
-	while node
-		next_node = node.next
-		node.delete
-		
-		node = next_node
-		
-		if next_node.nil? || node.type == :header
-			break
-		end
-	end
-	
-	node = contributing_header
-	replacement.each do |child|
-		node.insert_after(child)
-		node = child
-	end
+	node.replace_section(replacement)
 	
 	File.write(readme_path, root.to_markdown(width: 0))
 end
